@@ -1,10 +1,10 @@
 package HTTP::Message;
 
-# $Id: Message.pm,v 1.28 2003/10/23 19:11:32 uid39246 Exp $
+# $Id: Message.pm,v 1.34 2004/04/06 10:44:31 gisle Exp $
 
 use strict;
 use vars qw($VERSION $AUTOLOAD);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.28 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.34 $ =~ /(\d+)\.(\d+)/);
 
 require HTTP::Headers;
 require Carp;
@@ -19,6 +19,7 @@ sub new
     my($class, $header, $content) = @_;
     if (defined $header) {
 	Carp::croak("Bad header argument") unless ref $header;
+        $header = HTTP::Headers->new(@$header) if ref($header) eq "ARRAY";
 	$header = $header->clone;
     }
     else {
@@ -35,37 +36,63 @@ sub new
 sub clone
 {
     my $self  = shift;
-    my $clone = HTTP::Message->new($self->{'_headers'}, $self->{'_content'});
+    my $clone = HTTP::Message->new($self->headers,
+				   $self->content);
     $clone;
 }
 
 
 sub protocol { shift->_elem('_protocol',  @_); }
-sub content  { shift->_elem('_content',  @_); }
+
+sub content  {
+    my $self = shift;
+    if (defined(wantarray) && !exists $self->{_content}) {
+	$self->_content;
+    }
+    my $old = $self->{_content};
+    if (@_) {
+	$self->{_content} = shift;
+	delete $self->{_parts};
+    }
+    $old;
+}
 
 
 sub add_content
 {
     my $self = shift;
+    $self->_content unless exists $self->{_content};
     if (ref($_[0])) {
 	$self->{'_content'} .= ${$_[0]};  # for backwards compatability
     }
     else {
 	$self->{'_content'} .= $_[0];
     }
+    delete $self->{_parts};
 }
 
 
 sub content_ref
 {
     my $self = shift;
+    $self->_content unless exists $self->{_content};
+    delete $self->{_parts};
     \$self->{'_content'};
 }
 
 
 sub as_string
 {
-    "";  # To be overridden in subclasses
+    my($self, $eol) = @_;
+    $eol = "\n" unless defined $eol;
+
+    # The calculation of content might update the headers
+    # so we need to do that first.
+    my $content = $self->content;
+
+    return join("", $self->{'_headers'}->as_string($eol),
+		    $eol,
+		    $content);
 }
 
 
@@ -105,7 +132,7 @@ __END__
 
 =head1 NAME
 
-HTTP::Message - Class encapsulating HTTP messages
+HTTP::Message - HTTP style message base class
 
 =head1 SYNOPSIS
 
@@ -115,32 +142,13 @@ HTTP::Message - Class encapsulating HTTP messages
 
 =head1 DESCRIPTION
 
-An C<HTTP::Message> object contains some headers and a content (body).
+An C<HTTP::Message> object contains some headers and a content body.
 The class is abstract, i.e. it only used as a base class for
 C<HTTP::Request> and C<HTTP::Response> and should never instantiated
-as itself.
-
-The following methods are available:
+as itself.  The following methods are available:
 
 =over 4
 
-=item $mess = HTTP::Message->new
-
-This is the object constructor.  It should only be called internally
-by this library.  External code should construct C<HTTP::Request> or
-C<HTTP::Response> objects.
-
-=item $mess->clone()
-
-Returns a copy of the object.
-
-=item $mess->protocol
-
-=item $mess->protocol( $proto )
-
-Sets the HTTP protocol used for the message.  The protocol() is a string
-like C<HTTP/1.0> or C<HTTP/1.1>.
-
 =item $mess->content
 
 =item $mess->content( $content )
@@ -149,6 +157,10 @@ The content() method sets the content if an argument is given.  If no
 argument is given the content is not touched.  In either case the
 previous content is returned.
 
+Note that the content should be a string of bytes.  Strings in perl
+can contain characters outside the range of a byte.  The C<Encode>
+module can be used to turn such strings into a string of bytes.
+
 =item $mess->add_content( $data )
 
 The add_content() methods appends more data to the end of the current
@@ -163,53 +175,66 @@ for instance:
 
   ${$res->content_ref} =~ s/\bfoo\b/bar/g;
 
-=item $mess->headers;
+This example would modify the content buffer in-place.
 
-Return the embedded HTTP::Headers object.
+=item $mess->headers
+
+Returns the embedded HTTP::Headers object.
 
 =item $mess->headers_as_string
 
 =item $mess->headers_as_string( $endl )
 
 Call the as_string() method for the headers in the
-message.  This will be the same as:
+message.  This will be the same as
 
- $mess->headers->as_string
+    $mess->headers->as_string
 
 but it will make your program a whole character shorter :-)
 
+=item $mess->protocol
+
+=item $mess->protocol( $proto )
+
+Sets the HTTP protocol used for the message.  The protocol() is a string
+like C<HTTP/1.0> or C<HTTP/1.1>.
+
+=item $mess->clone
+
+Returns a copy of the message object.
+
 =back
 
-All unknown C<HTTP::Message> methods are delegated to the
+All methods unknown to C<HTTP::Message> itself are delegated to the
 C<HTTP::Headers> object that is part of every message.  This allows
 convenient access to these methods.  Refer to L<HTTP::Headers> for
 details of these methods:
 
-  $mess->header($field => $val);
-  $mess->push_header($field => $val);
-  $mess->init_header($field => $val);
-  $mess->remove_header($field);
-  $mess->scan(\&doit);
+    $mess->header( $field => $val )
+    $mess->push_header( $field => $val )
+    $mess->init_header( $field => $val )
+    $mess->remove_header( $field )
+    $mess->scan( \&doit )
 
-  $mess->date;
-  $mess->expires;
-  $mess->if_modified_since;
-  $mess->if_unmodified_since;
-  $mess->last_modified;
-  $mess->content_type;
-  $mess->content_encoding;
-  $mess->content_length;
-  $mess->content_language
-  $mess->title;
-  $mess->user_agent;
-  $mess->server;
-  $mess->from;
-  $mess->referer;
-  $mess->www_authenticate;
-  $mess->authorization;
-  $mess->proxy_authorization;
-  $mess->authorization_basic;
-  $mess->proxy_authorization_basic;
+    $mess->date
+    $mess->expires
+    $mess->if_modified_since
+    $mess->if_unmodified_since
+    $mess->last_modified
+    $mess->content_type
+    $mess->content_encoding
+    $mess->content_length
+    $mess->content_language
+    $mess->title
+    $mess->user_agent
+    $mess->server
+    $mess->from
+    $mess->referer
+    $mess->www_authenticate
+    $mess->authorization
+    $mess->proxy_authorization
+    $mess->authorization_basic
+    $mess->proxy_authorization_basic
 
 =head1 COPYRIGHT
 
